@@ -31,21 +31,21 @@ class ConfigData:
             for k,v in self.data["controls"].items():
                 roomName = ''
                 if 'room' in v:
-                    roomName = "{0} ".format(self.get_room_name(v["room"]))
+                    roomName = self.get_room_name(v["room"])
 
                 catName = ''
                 if 'cat' in v:
-                    catName = "{0} ".format(self.get_cat_name(v["cat"]))
+                    catName = self.get_cat_name(v["cat"])
 
                 if v["type"] == 'Jalousie':
-                    self.covers[k] = LoxJalousie(k, roomName + v["name"], catName, v["type"])
+                    self.covers[k] = LoxJalousie(k, v["name"], v["type"], roomName, catName, v["details"])
                     _LOGGER.debug("  Map states for Jalousie")
                     for tk,tv in v["states"].items():
                         _LOGGER.debug("    state: {0} = {1}".format(tv, tk))
                         self.fieldmap[tv] = {"device": self.covers[k], "stateName": tk}
 
                 if v["type"] == 'ClimateController':
-                    self.climatecontrollers[k] = LoxClimateController(k, roomName + v["name"], v["type"])
+                    self.climatecontrollers[k] = LoxClimateController(k, v["name"], v["type"], roomName, catName, v["details"])
                     
                     #_LOGGER.debug("  Map ClimateController {0}".format(k))
                     #self.fieldmap[k] = {"device": self.climatecontrollers[k], "stateName": tk}
@@ -56,14 +56,14 @@ class ConfigData:
                         self.fieldmap[tv] = {"device": self.climatecontrollers[k], "stateName": tk}
 
                 if v["type"] == 'LightControllerV2':
-                    self.scenes[k] = LoxLightControllerV2(k, roomName + v["name"], v["type"])
+                    self.scenes[k] = LoxLightControllerV2(k, v["name"], v["type"], roomName, catName, v["details"])
                     _LOGGER.debug("  Map states for LightControllerV2")
                     for tk,tv in v["states"].items():
                         _LOGGER.debug("    state: {0} = {1}".format(tv, tk))
                         self.fieldmap[tv] = {"device": self.scenes[k], "stateName": tk}
 
                 if v["type"] == 'IRoomControllerV2':
-                    self.roomcontrollers[k] = LoxIntelligentRoomControllerV2(k, roomName + v["name"], v["type"])
+                    self.roomcontrollers[k] = LoxIntelligentRoomControllerV2(k, v["name"], v["type"], roomName, catName, v["details"])
                     _LOGGER.debug("  Map states for IRoomControllerV2")
                     for tk,tv in v["states"].items():
                         _LOGGER.debug("    state: {0} = {1}".format(tv, tk))
@@ -71,14 +71,14 @@ class ConfigData:
 
                 if v["type"] == 'InfoOnlyAnalog':
                     _LOGGER.debug("  InfoOnlyAnalog - {0}".format(k))
-                    self.sensors[k] = LoxInfoOnlyAnalog(k, roomName + v["name"], v["type"], v)
+                    self.sensors[k] = LoxInfoOnlyAnalog(k, v["name"], v["type"], roomName, catName, v["details"])
 
                     for tk,tv in v["states"].items():
                         _LOGGER.debug("    state: {0} = {1}".format(tv, tk))
                         self.fieldmap[tv] = {"device": self.sensors[k], "stateName": tk}
 
                 if v["type"] == 'InfoOnlyDigital':
-                    self.binarysensors[k] = LoxInfoOnlyDigital(k, roomName + v["name"], catName, v["details"], v["type"], v)
+                    self.binarysensors[k] = LoxInfoOnlyDigital(k, v["name"], v["type"], roomName, catName, v["details"])
                     _LOGGER.debug("  Map states for InfoOnlyDigital")
                     for tk,tv in v["states"].items():
                         _LOGGER.debug("    state: {0} = {1}".format(tv, tk))
@@ -88,11 +88,11 @@ class ConfigData:
                     for sk,sv in v["subControls"].items():
                         _LOGGER.debug("  Adding Light: {0} {1}".format(sk, sv["name"]))
                         if sv["type"] == 'Switch':
-                            self.devices[sk] = LoxSwitch(sk, roomName + sv["name"], sv["type"])
+                            self.devices[sk] = LoxSwitch(sk, sv["name"], sv["type"], roomName, catName, sv["details"])
                         elif sv["type"] == 'Dimmer':
-                            self.devices[sk] = LoxDimmer(sk, roomName + sv["name"], sv["type"])
+                            self.devices[sk] = LoxDimmer(sk, sv["name"], sv["type"], roomName, catName, sv["details"])
                         elif sv["type"] == 'ColorPickerV2':
-                            self.devices[sk] = LoxColorPickerV2(sk, roomName + sv["name"], sv["type"])
+                            self.devices[sk] = LoxColorPickerV2(sk, sv["name"], sv["type"], roomName, catName, sv["details"])
 
                         _LOGGER.debug("  Map states for Light")
                         for stk,stv in sv["states"].items():
