@@ -5,10 +5,13 @@ _LOGGER = logging.getLogger(__name__)
 class LoxClimateController:
     """Class for node abstraction."""
 
-    def __init__(self, id, name, device_type):
+    def __init__(self, id, name, device_type, room, cat, details):
         self._id = id
         self._name = name
         self._device_type = device_type
+        self._room = room
+        self._cat = cat
+        self._details = details
         self.async_callbacks = []
             
     @property
@@ -17,14 +20,26 @@ class LoxClimateController:
 
     @property
     def name(self):
-        return self._name
+        return self._room + " " + self._name
 
     @property
     def device_type(self):
         return self._device_type
 
     @property
-    def manufacturername(self):
+    def room(self):
+        return self._room
+
+    @property
+    def category(self):
+        return self._cat
+
+    @property
+    def details(self):
+        return self._details
+
+    @property
+    def manufacturer_name(self):
         return 'Loxone'    
 
     def register_async_callback(self, async_callback):
