@@ -5,11 +5,13 @@ _LOGGER = logging.getLogger(__name__)
 class LoxJalousie:
     """Class for node abstraction."""
 
-    def __init__(self, id, name, cat, device_type):
+    def __init__(self, id, name, device_type, room, cat, details):
         self._id = id
         self._name = name
-        self._cat = cat
         self._device_type = device_type
+        self._room = room
+        self._cat = cat
+        self._details = details
         self._position = False
         self.async_callbacks = []
             
@@ -19,14 +21,27 @@ class LoxJalousie:
 
     @property
     def name(self):
-        return self._name
+        return self._room + " " + self._name
 
     @property
     def device_type(self):
         return self._device_type
 
     @property
-    def manufacturername(self):
+    def room(self):
+        return self._room
+
+    @property
+    def category(self):
+        return self._cat
+
+    @property
+    def details(self):
+        return self._details
+
+
+    @property
+    def manufacturer_name(self):
         return 'Loxone'    
 
     @property
